==> angelssmelting_0.3.5.zip: angelssmelting_0.3.5/prototypes/items/angels-tungsten.lua <==
data:extend(
{
  {
    type = "item",
    name = "tungsten-ore",
    icon = "__angelssmelting__/graphics/icons/ore-tungsten.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "a",
    stack_size = 200
  },
  {
    type = "item",
    name = "processed-tungsten",
    icon = "__angelssmelting__/graphics/icons/processed-tungsten.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-tungsten",
    icon = "__angelssmelting__/graphics/icons/pellet-tungsten.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-ammonium-paratungstate",
    icon = "__angelssmelting__/graphics/icons/solid-ammonium-paratungstate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-tungsten-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-tungsten-oxide.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-tungsten",
    icon = "__angelssmelting__/graphics/icons/powder-tungsten.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "f",
    stack_size = 200
  },
  {
    type = "item",
    name = "casting-powder-tungsten",
    icon = "__angelssmelting__/graphics/icons/powder-tungsten.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "g",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-tungstic-acid",
    icon = "__angelssmelting__/graphics/icons/liquid-tungstic-acid.png",
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
  },
  {
    type = "fluid",
    name = "gas-tungsten-hexafluoride",
    icon = "__angelssmelting__/graphics/icons/gas-tungsten-hexafluoride.png",
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
  },
  {
    type = "item",
    name = "angels-plate-tungsten",
    icon = "__angelssmelting__/graphics/icons/plate-tungsten.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten-casting",
    order = "h",
    stack_size = 200
  },
}
)

==> angelssmelting_0.4.6.zip: angelssmelting_0.4.6/prototypes/items/angels-tungsten.lua <==
data:extend(
{
  {
    type = "item",
    name = "tungsten-ore",
    icon = "__angelssmelting__/graphics/icons/ore-tungsten.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "a",
    stack_size = 200
  },
  {
    type = "item",
    name = "processed-tungsten",
    icon = "__angelssmelting__/graphics/icons/processed-tungsten.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-tungsten",
    icon = "__angelssmelting__/graphics/icons/pellet-tungsten.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-ammonium-paratungstate",
    icon = "__angelssmelting__/graphics/icons/solid-ammonium-paratungstate.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-tungsten-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-tungsten-oxide.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-tungsten",
    icon = "__angelssmelting__/graphics/icons/powder-tungsten.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "f",
    stack_size = 200
  },
  {
    type = "item",
    name = "casting-powder-tungsten",
    icon = "__angelssmelting__/graphics/icons/powder-tungsten.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten",
    order = "g",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-tungstic-acid",
    icon = "__angelssmelting__/graphics/icons/liquid-tungstic-acid.png",
	icon_size = 32,
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 136/255, g = 98/255, b = 65/255},
    flow_color = {r = 136/255, g = 98/255, b = 65/255},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
  },
  {
    type = "fluid",
    name = "gas-tungsten-hexafluoride",
    icon = "__angelssmelting__/graphics/icons/gas-tungsten-hexafluoride.png",
	icon_size = 32,
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 136/255, g = 98/255, b = 65/255},
    flow_color = {r = 136/255, g = 98/255, b = 65/255},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
  },
  {
    type = "item",
    name = "angels-plate-tungsten",
    icon = "__angelssmelting__/graphics/icons/plate-tungsten.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-tungsten-casting",
    order = "h",
    stack_size = 200
  },
}
)
